Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(425)

Unified Diff: ui/base/win/window_impl.h

Issue 11417003: Reland r167487: Get full WebPluginInfo for the PDF plug-in before enabling it for print preview. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/win/window_impl.h
diff --git a/ui/base/win/window_impl.h b/ui/base/win/window_impl.h
index 2200393446da38546fe32507f5df1ece91245adf..1f3b5d3cf88e019518bc6cc29cb4fcc4d74dfc5c 100644
--- a/ui/base/win/window_impl.h
+++ b/ui/base/win/window_impl.h
@@ -90,9 +90,9 @@ class UI_EXPORT WindowImpl : public MessageMapInterface {
WPARAM w_param,
LPARAM l_param);
// Gets the window class name to use when creating the corresponding HWND.
// If necessary, this registers the window class.
- std::wstring GetWindowClassName();
+ ATOM GetWindowClassAtom();
// All classes registered by WindowImpl start with this name.
static const wchar_t* const kBaseClassName;
@@ -90,9 +90,9 @@ class UI_EXPORT WindowImpl : public MessageMapInterface {
WPARAM w_param,
LPARAM l_param);
- // Gets the window class name to use when creating the corresponding HWND.
+ // Gets the window class atom to use when creating the corresponding HWND.
// If necessary, this registers the window class.

Powered by Google App Engine
This is Rietveld 408576698